@@ -19,7 +19,7 @@ const QString KEY_INIT( "initialized" );
 const QString KEY_FOLDER( "folder" );
 const QString KEY_FILENAME( "file" );
 const QString KEY_FILEPOS( "resume" );
-const QString DEFAULT_SEARCHFOLDER( "/home/user/MyDocs/Videos" );
+const QString DEFAULT_SEARCHFOLDER( "/home/user/MyDocs/.videos" );
 
 class Settings : public QObject {
     Q_OBJECT
