@@ -16,25 +16,25 @@ MainWindow::MainWindow()
     buttonFont.setPixelSize( 25 );
 
     int buttonWidth = 150;
-    int buttonHeight = 80;
+    int buttonHeight = 70;
     int buttonLeftOffset = 15;
 
     m_playbutton = new QPushButton( tr( "Play" ), this );
     m_playbutton->setFont( buttonFont );
-    m_playbutton->setGeometry( buttonLeftOffset, 20, buttonWidth, buttonHeight );
+    m_playbutton->setGeometry( buttonLeftOffset, 40, buttonWidth, buttonHeight );
     m_playbutton->setEnabled( false );
     m_resumebutton = new QPushButton( tr( "Resume" ), this );
     m_resumebutton->setFont( buttonFont );
-    m_resumebutton->setGeometry( buttonLeftOffset, 120, buttonWidth, buttonHeight );
+    m_resumebutton->setGeometry( buttonLeftOffset, 135, buttonWidth, buttonHeight );
     m_resumebutton->setEnabled( false );
     QPushButton* settingsbutton = new QPushButton( tr( "Folders" ), this );
     settingsbutton->setFont( buttonFont );
-    settingsbutton->setGeometry( buttonLeftOffset, 220, buttonWidth, buttonHeight );
+    settingsbutton->setGeometry( buttonLeftOffset, 230, buttonWidth, buttonHeight );
     QPushButton* helpButton = new QPushButton( tr( "Info" ), this );
     helpButton->setFont( buttonFont );
-    helpButton->setGeometry( buttonLeftOffset, 320, buttonWidth, buttonHeight );
+    helpButton->setGeometry( buttonLeftOffset, 325, buttonWidth, buttonHeight );
 
-    m_fileList = new QTableView( this );// new QTableWidget( 0, 3, this );
+    m_fileList = new QTableView( this );
     m_fileList->setItemDelegate( new QItemDelegate( this ) );
     m_fileList->setGeometry( 190, 5, 605, 415 );
 
@@ -58,13 +58,6 @@ MainWindow::MainWindow()
     connect( helpButton, SIGNAL( clicked() ),
              this, SLOT( helpButtonPressed() ) );
 
-#if 0
-    connect( m_fileList, SIGNAL( cellDoubleClicked( int, int ) ),
-             this, SLOT( fileSelected( int, int ) ) );
-
-    connect( m_fileList, SIGNAL( cellClicked( int, int ) ),
-        this, SLOT( cellClicked( int, int ) ) );
-#endif
     connect( m_fileList, SIGNAL( doubleClicked( const QModelIndex & ) ),
         this, SLOT( fileSelected() ) );
 
@@ -102,18 +95,18 @@ void MainWindow::updateFileList( const QList<VideoFile*>& files )
         QList<QStandardItem*> row;
 
         QStandardItem *fileNameItem = new QStandardItem( files[i]->file().fileName() );
-        fileNameItem->setBackground( QBrush( QColor( ( 256 * i / fileCount ) << 16 | 80 ) ) );
+        fileNameItem->setBackground( QBrush( QColor( ( 100 * i / fileCount ) << 16 | 50 ) ) );
         fileNameItem->setFlags( fileNameItem->flags() ^ Qt::ItemIsEditable );
         row.append( fileNameItem );
 
         int size = int( 0.5 + files[i]->file().size() / ( 1024 * 1024 ) );
         QStandardItem* sizeItem = new QStandardItem(  tr("%1 MB").arg( size ) );
-        sizeItem->setBackground( QBrush( QColor( ( 256 * i / fileCount ) << 16 | 80 ) ) );
+        sizeItem->setBackground( QBrush( QColor( ( 100 * i / fileCount ) << 16 | 50 ) ) );
         sizeItem->setFlags( sizeItem->flags() ^ Qt::ItemIsEditable );
         row.append( sizeItem );
 
         QStandardItem* resumePosItem = new QStandardItem( tr("%1").arg( toHHMMSS( files[i]->resumePos() ) ) );
-        resumePosItem->setBackground( QBrush( QColor( ( 256 * i / fileCount ) << 16 | 80 ) ) );
+        resumePosItem->setBackground( QBrush( QColor( ( 100 * i / fileCount ) << 16 | 50 ) ) );
         resumePosItem->setFlags( resumePosItem->flags() ^ Qt::ItemIsEditable );
         row.append( resumePosItem );
 
@@ -197,7 +190,11 @@ void MainWindow::resort( int column )
 {
     if ( m_sortByColumn != column ) {
         m_sortByColumn = column;
-        m_sortOrder = Qt::AscendingOrder;
+        if ( column == 2 ) { // if sort by resume pos is selected for the first time sort descending
+            m_sortOrder = Qt::DescendingOrder;
+        } else {
+            m_sortOrder = Qt::AscendingOrder;
+        }
     } else {
         if ( m_sortOrder == Qt::AscendingOrder ) {
             m_sortOrder = Qt::DescendingOrder;
